@@ -5,7 +5,8 @@ import httpx
 from httpx import Response
 from . import GQLException
 
-TIMEOUT = os.getenv("DGRAPH_TIMEOUT", 25.0)
+TIMEOUT = float(os.getenv("GQL_CLIENT_TIMEOUT", "25"))
+print(f"{TIMEOUT=}")
 
 client_sync = httpx.Client(timeout=TIMEOUT)
 client = httpx.AsyncClient(timeout=TIMEOUT)
@@ -42,7 +43,7 @@ async def gql(
     start = time.time()
     json = {"query": query_str, "variables": variables or {}}
     if use_one_time:
-        async with httpx.AsyncClient() as onetime_client:
+        async with httpx.AsyncClient(timeout=TIMEOUT) as onetime_client:
             response = await onetime_client.post(url=url, json=json)
     else:
         response = await client.post(url=url, json=json)
