@@ -463,12 +463,12 @@ async def {edge_name}(self, resolver: {resolver_name} = None, refresh: bool = Fa
             upsert_str = ""
         return f"""
 @classmethod
-async def add(cls, *, input: {self.node_config.add_model}, resolver: {self.resolver_name} = None{upsert_str}) -> {self.node_name}:
-    return (await cls.add_many(inputs=[input], resolver=resolver, upsert=upsert))[0]
+async def add(cls, *, input: {self.node_config.add_model}, resolver: {self.resolver_name} = None{upsert_str}, use_one_time: bool = False) -> {self.node_name}:
+    return (await cls.add_many(inputs=[input], resolver=resolver, upsert=upsert, use_one_time=use_one_time))[0]
 
 @classmethod
-async def add_many(cls, *, inputs: List[{self.node_config.add_model}], resolver: {self.resolver_name} = None{upsert_str}) -> List[{self.node_name}]:
-    return await cls._add(inputs=inputs, given_resolver=resolver, upsert={"upsert" if has_upsert else "None"})
+async def add_many(cls, *, inputs: List[{self.node_config.add_model}], resolver: {self.resolver_name} = None{upsert_str}, use_one_time: bool = False) -> List[{self.node_name}]:
+    return await cls._add(inputs=inputs, given_resolver=resolver, upsert={"upsert" if has_upsert else "None"}, use_one_time=use_one_time)
         """
 
     def build_update(self) -> str:
